EC2 Anypoint Connector Demo - Instances, Elastic Block Store, Security Groups and Network Interfaces
==========================================================================================================

## Introduction

The present demo application provides a **complete workflow** to sequentially invoke some of EC2's **standard operations**.

## Prerequisites

* Java 7
* Anypoint Studio 6.0.x or higher
* Mule Runtime 3.8.x EE or higher
* DataWeave
* Access to a Amazon S3

## Import the project

* Go to **File > Import**
* Select **Anypoint Studio Project from External Location** (under the parent folder "Anypoint Studio")
* Provide the root path to the demo project folder.
* Select Mule Runtime (3.8.x EE).
* Click **Finish**.
* Set EC2 credentials inside the file `src/main/app/mule-app.properties`. This may vary depending on the selected connection configuration. The current demo uses **EC2 Access Key, Secret Key**:

    ```
    ec2.accessKey=**************
    ec2.secretKey=**************
    ec2.region=*****************
    ```

* Open the **Global Element Configuration**.
* Fill Access Key and Secret Key as `${ec2.accessKey}`, `${ec2.secretKey}` and `${ec2.region}` respectively. 
* Click the **Test Connection** button to ensure there is connectivity with the sandbox. A successful message should pop-up.

* Open a browser and access the URL **http://localhost:8081**. You should see the demo application deployed:

## Run the demo

### Start Instances

![Demo Start Instances](images/Demo-Start-Instances.png)

* Provide a **Instance Id** to be started.
* Click the button **Start Instances** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**

### Stop Instances

![Demo Stop Instances](images/Demo-Stop-Instances.png)

* Provide a **Instance Id** to be stop.
* Click the button **Stop Instances** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**


### Monitor Instances

![Demo Monitor Instances](images/Demo-Monitor-Instances.png)

* Provide a **Instance Id** to monitor.
* Click the button **Monitor Instances** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**


### Unmonitor Instances

![Demo Unmonitor Instances](images/Demo-Unmonitor-Instances.png)

* Provide a **Instance Id** to unmonitor.
* Click the button **Unmonitor Instances** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**

### Describe Instances

![Demo Describe Instances](images/Demo-Describe-Instances.png)

* Provide a **Instance Id** to describe.
* Click the button **Describe Instances** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box** as JSON object.

### Assign Ipv6 Addresses

![Demo Assign Ipv6 Addresses](images/Demo-Assign-Ipv6-Addresses.png)

* Provide a **Network Interface Id** value.
* Provide a **Ipv6 Address Count** which is no of IP's need to be assigned.
* Click the button **Assign Ipv6 Addresses** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**.
    
### Unassign Ipv6 Addresses

![Demo Unassign Ipv6 Addresses](images/Demo-Unassign-Ipv6-Addresses.png)

* Provide a **Network Interface Id** value.
* Provide a **Ipv6 Address(give one IPv6 address at a time)** to be un-assigned.
* Click the button **Unassign Ipv6 Addresses** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**.
    
### Create Volume

![Demo Create Volume](images/Demo-Create-Volume.png)

* Provide a **Availability Zone** value.
* Provide a **Size (in GB, example: 1)** value.
* Click the button **Create Volume** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**.
    
### Attach Volume

![Demo Attach Volume](images/Demo-Attach-Volume.png)

* Provide a **Volume Id** value.
* Provide a **Instance Id** to be attach.
* Provide a **Device (for example, /dev/sdh or xvdh)** value.
* Click the button **Attach Volume** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**.
    
### Detach Volume

![Demo Detach Volume](images/Demo-Detach-Volume.png)

* Provide a **Volume Id** value.
* Click the button **Detach Volume** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**.
    
### Delete Volume

![Demo Delete Volume](images/Demo-Delete-Volume.png)

* Provide a **Volume Id** value.
* Click the button **Delete Volume** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**.
    
### Create Security Group

![Demo Create Security Group](images/Demo-Create-Security-Group.png)

* Provide a **VPC Id** value.
* Provide a **Group Name** value.
* Provide a **Description** value.
* Click the button **Create Security Group** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box**.
    
### Describe Security Groups

![Demo Describe Security Groups](images/Demo-Describe-Security-Groups.png)

* Provide a **Group Id** value.
* Click the button **Describe Security Groups** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box** as JSON Object.
    
### Delete Security Group

![Demo Delete Security Group](images/Demo-Delete-Security-Group.png)

* Provide a **Group Id** value.
* Click the button **Delete Security Group** and wait a few moments to finish processing.
* If successful:
    * You should see the result in the below **Result Box** as JSON Object.

## See more

* For additional technical information on the EC2 Connector, visit our [technical reference documentation](http://mulesoft.github.io/ec2-connector/) or refer to the [S3 Documentation Site](https://docs.mulesoft.com/mule-user-guide/v/3.8/amazon-s3-connector).
* For more information on the EC2 API, go to the [EC2 API documentation page](https://aws.amazon.com/documentation/ec2/).